@@ -93,8 +93,6 @@ void KScreenDaemon::init()
 
     new KScreenAdaptor(this);
 
-    connect(Device::self(), SIGNAL(lidIsClosedChanged(bool,bool)), SLOT(lidClosedChanged(bool)));
-
     m_buttonTimer->setInterval(300);
     m_buttonTimer->setSingleShot(true);
     connect(m_buttonTimer, &QTimer::timeout, this, &KScreenDaemon::applyGenericConfig);
@@ -107,6 +105,18 @@ void KScreenDaemon::init()
     m_changeCompressor->setSingleShot(true);
     connect(m_changeCompressor, &QTimer::timeout, this, &KScreenDaemon::applyConfig);
 
+
+    connect(Device::self(), &Device::lidClosedChanged, this, &KScreenDaemon::lidClosedChanged);
+    connect(Device::self(), &Device::resumingFromSuspend,
+            [&]() {
+                qCDebug(KSCREEN_KDED) << "Resumed from suspend, checking for screen changes";
+                // We don't care about the result, we just want to force the backend
+                // to query XRandR so that it will detect possible changes that happened
+                // while the computer was suspended, and will emit the change events.
+                new KScreen::GetConfigOperation(KScreen::GetConfigOperation::NoEDID, this);
+            });
+
+
     connect(Generator::self(), &Generator::ready,
             this, &KScreenDaemon::applyConfig);
 
@@ -253,51 +263,13 @@ void KScreenDaemon::setMonitorForChanges(bool enabled)
 
     qCDebug(KSCREEN_KDED) << "Monitor for changes: " << enabled;
     m_monitoring = enabled;
-
-    const KScreen::OutputList outputs = m_monitoredConfig->outputs();
-    Q_FOREACH(const KScreen::OutputPtr &output, outputs) {
-        if (m_monitoring) {
-            enableMonitor(output);
-        } else {
-            disableMonitor(output);
-        }
+    if (m_monitoring) {
+        connect(KScreen::ConfigMonitor::instance(), &KScreen::ConfigMonitor::configurationChanged,
+                this, &KScreenDaemon::configChanged, Qt::UniqueConnection);
+    } else {
+        disconnect(KScreen::ConfigMonitor::instance(), &KScreen::ConfigMonitor::configurationChanged,
+                   this, &KScreenDaemon::configChanged);
     }
 }
 
-void KScreenDaemon::enableMonitor(const KScreen::OutputPtr &output)
-{
-    connect(output.data(), &KScreen::Output::currentModeIdChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::isEnabledChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::isPrimaryChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::outputChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::clonesChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::posChanged,
-            this, &KScreenDaemon::configChanged);
-    connect(output.data(), &KScreen::Output::rotationChanged,
-            this, &KScreenDaemon::configChanged);
-}
-
-void KScreenDaemon::disableMonitor(const KScreen::OutputPtr &output)
-{
-    disconnect(output.data(), &KScreen::Output::currentModeIdChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::isEnabledChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::isPrimaryChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::outputChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::clonesChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::posChanged,
-               this, &KScreenDaemon::configChanged);
-    disconnect(output.data(), &KScreen::Output::rotationChanged,
-               this, &KScreenDaemon::configChanged);
-}
-
 #include "daemon.moc"
